@@ -19,6 +19,7 @@ from snowav.database.tables import Base, RunMetadata, Watershed, Basin, \
 # Fix these two by pulling smrf and awsm versions from netcdf
 try:
     import smrf
+
     smrf_version = smrf.__version__
 except:
     smrf_version = 'unknown'
@@ -26,6 +27,7 @@ except:
 try:
     warnings.filterwarnings("ignore")
     import awsm
+
     warnings.filterwarnings("default")
     awsm_version = awsm.__version__
 except:
@@ -214,6 +216,82 @@ class Database(object):
         results {DataFrame}: query results
         """
 
+        # tparams = {Pixels: {(Pixels.model_row, '==', int(pt[0]))}}
+
+        unique_tables = set(params.keys())
+        tables = list(params.keys())
+        ntables = len(unique_tables)
+
+        if ntables < 1 or ntables > 2:
+            raise ValueError("params must have <= 2 unique tables")
+
+        dbsession = sessionmaker(bind=self.engine)
+        session = dbsession()
+
+        from snowav.database.tables import Pixels, PixelsData
+
+        n = 0
+        for t in params.keys():
+            print(t)
+            if t == 'Pixels':
+                table = Pixels
+            if t == 'PixelsData':
+                table = PixelsData
+
+            for f in params[t]:
+                print(f)
+                raw = f
+
+                try:
+                    key, op, value = raw
+                except ValueError:
+                    raise Exception('Invalid filter: %s' % raw)
+
+                column = getattr(table, key, None)
+
+                if not column:
+                    raise Exception('Invalid filter column: %s' % key)
+                if op == 'in':
+                    if isinstance(value, list):
+                        filt = column.in_(value)
+                    else:
+                        filt = column.in_(value.split(','))
+                else:
+                    try:
+                        attr = list(filter(
+                            lambda e: hasattr(column, e % op),
+                            ['%s', '%s_', '__%s__']
+                        ))[0] % op
+                    except IndexError:
+                        raise Exception('Invalid filter operator: %s' % op)
+                    if value == 'null':
+                        value = None
+
+                    if n == 0:
+                        filt = getattr(column, attr)(value)
+                        print("FIRST\n", filt)
+                    else:
+                        t = getattr(column, attr)(value)
+                        filt = and_(filt, t)
+                        print('AND\n ', filt)
+
+                n += 1
+
+        if ntables == 1:
+            qry = session.query(table).filter(filt)
+        else:
+            qry = session.query(tables[0]).join(tables[1])
+
+        # qry = qry.filter(filt)
+
+        print('QRY\n', qry)
+        results = pd.read_sql(qry.statement, qry.session.connection())
+        session.close()
+
+        print(results)
+        print(x)
+
+        """
         if index is None:
             index = []
         if columns is None:
@@ -233,46 +311,17 @@ class Database(object):
         if not isinstance(index, list):
             raise TypeError("index must be a list")
 
-        # make database connection
-        try:
-            dbsession = sessionmaker(bind=self.engine)
-        except Exception as e:
-            print(e)
-            if logger is not None:
-                logger.error(" Failed connecting to database")
-            else:
-                print("Failed connecting to database")
-
-        # make session
+        dbsession = sessionmaker(bind=self.engine)
         session = dbsession()
-
-        for n, table in enumerate(params.keys()):
-
-            # store the first if there are two unique tables being queried
-            if ntables > 1 and n == 0:
-                tbl_o = getattr(ta, table)
-
-            tbl = getattr(ta, table)
-
-            try:
-                col, op, value = params[table]
-            except ValueError:
-                raise Exception('Invalid filter: {}'.format(table))
-
-            if col not in list(vars(tbl)):
-                raise Exception("Invalid column: {}".format(col))
-
-            # TODO: add filter options to query
-            # translate operator
-            # op = self.operators(op)
-            # field = getattr(tbl, col)
+        tables = list(params.keys())
+        ntables = len(tables)
 
         if ntables == 1:
-            __query = session.query(tbl)
+            qry = session.query(tables[0]).filter_by(**params[tables[0]])
         else:
-            __query = session.query(tbl, tbl_o).join(tbl)
+            qry = session.query(tables[0], tables[1])
 
-        results = pd.read_sql(__query.statement, __query.session.connection())
+        results = pd.read_sql(qry.statement, qry.session.connection())
         session.close()
 
         # apply columns
@@ -307,6 +356,7 @@ class Database(object):
                 results.sort_index(inplace=True)
 
         return results
+        """
 
     def delete(self, dbtable, kwargs, logger=None):
         """ Delete database records.
