@@ -97,7 +97,7 @@ class AwsmInputsOutputs(object):
                           'derivatives': {'requires': [], 'products': []},
                           'unit_type': 'percent',
                           'description': '% liquid water saturation',
-                          'units': 'percent',
+                          'units': '%',
                           'calculate': 'mean',
                           'table': 'Results',
                           'file': 'snow.nc'},
@@ -218,7 +218,7 @@ class AwsmInputsOutputs(object):
                           'derivatives': {'requires': [], 'products': []},
                           'unit_type': 'dimensionless',
                           'description': 'cloud factor',
-                          'units': 'dimensionless',
+                          'units': 'unitless',
                           'calculate': 'mean',
                           'table': 'Inputs',
                           'file': 'cloud_factor.nc'},
@@ -277,7 +277,7 @@ class AwsmInputsOutputs(object):
                                                        'rain']},
                           'unit_type': 'percent',
                           'description': 'percent of precipitation that is snow',
-                          'units': 'mm',
+                          'units': '%',
                           'calculate': 'mean',
                           'table': 'Inputs',
                           'file': 'percent_snow.nc'},
